@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -100,11 +100,14 @@ struct _HklVector
 	double data[3];
 };
 
+HKLAPI void hkl_vector_init(HklVector *self, double x, double y, double z);
+
 /**************/
 /* Quaternion */
 /**************/
 
 typedef struct _HklQuaternion HklQuaternion;
+typedef struct _HklMatrix HklMatrix; /* forwarded declaration */
 
 struct _HklQuaternion
 {
@@ -113,12 +116,12 @@ struct _HklQuaternion
 
 typedef darray(const char *) darray_string;
 
+HKLAPI void hkl_quaternion_to_matrix(const HklQuaternion *self, HklMatrix *m) HKL_ARG_NONNULL(1, 2);
+
 /**********/
 /* Matrix */
 /**********/
 
-typedef struct _HklMatrix HklMatrix;
-
 HKLAPI HklMatrix *hkl_matrix_new(void);
 
 HKLAPI HklMatrix *hkl_matrix_new_full(double m11, double m12, double m13,
@@ -219,6 +222,7 @@ HKLAPI void hkl_detector_fprintf(FILE *f, const HklDetector *self) HKL_ARG_NONNU
 typedef struct _HklGeometry HklGeometry;
 typedef struct _HklGeometryList HklGeometryList;
 typedef struct _HklGeometryListItem HklGeometryListItem;
+typedef struct _HklSample HklSample; /* forwarded declaration */
 
 /* HklGeometry */
 
@@ -260,6 +264,12 @@ HKLAPI void hkl_geometry_randomize(HklGeometry *self) HKL_ARG_NONNULL(1);
 HKLAPI int hkl_geometry_set_values_v(HklGeometry *self, HklUnitEnum unit_type,
 				     GError **error, ...) HKL_ARG_NONNULL(1) HKL_WARN_UNUSED_RESULT;
 
+HKLAPI HklQuaternion hkl_geometry_sample_rotation_get(const HklGeometry *self,
+						      const HklSample *sample) HKL_ARG_NONNULL(1, 2);
+
+HKLAPI HklQuaternion hkl_geometry_detector_rotation_get(const HklGeometry *self,
+							const HklDetector *detector) HKL_ARG_NONNULL(1, 2);
+
 HKLAPI void hkl_geometry_fprintf(FILE *file, const HklGeometry *self) HKL_ARG_NONNULL(1, 2);
 
 /* HklGeometryList */
@@ -286,7 +296,6 @@ HKLAPI const HklGeometry *hkl_geometry_list_item_geometry_get(const HklGeometryL
 /**********/
 
 typedef struct _HklLattice HklLattice;
-typedef struct _HklSample HklSample;
 typedef struct _HklSampleReflection HklSampleReflection;
 
 /* Lattice */
