@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -31,6 +31,7 @@
 #include <sys/types.h>                  // for uint
 #include "hkl-factory-private.h"
 #include "hkl-axis-private.h"           // for HklAxis, etc
+#include "hkl-detector-private.h"
 #include "hkl-geometry-private.h"       // for _HklGeometry, etc
 #include "hkl-interval-private.h"       // for HklInterval
 #include "hkl-macros-private.h"         // for HKL_MALLOC
@@ -50,7 +51,8 @@
  * die if try to add an axis with the same name but a different axis_v
  */
 static size_t hkl_geometry_add_rotation(HklGeometry *self,
-					const char *name, const HklVector *axis_v)
+					const char *name, const HklVector *axis_v,
+					const HklUnit *punit)
 {
 	uint i = 0;
 	HklParameter **parameter;
@@ -74,7 +76,7 @@ static size_t hkl_geometry_add_rotation(HklGeometry *self,
 	}
 
 	/* no so create and add it to the list */
-	darray_append(self->axes, hkl_parameter_new_axis(name, axis_v));
+	darray_append(self->axes, hkl_parameter_new_axis(name, axis_v, punit));
 
 	return darray_size(self->axes) - 1;
 }
@@ -166,6 +168,13 @@ static void hkl_holder_update(HklHolder *self)
 
 HklParameter *hkl_holder_add_rotation_axis(HklHolder *self,
 					   const char *name, double x, double y, double z)
+{
+	return hkl_holder_add_rotation_axis_with_punit(self, name, x, y, z, &hkl_unit_angle_deg);
+}
+
+HklParameter *hkl_holder_add_rotation_axis_with_punit(HklHolder *self,
+						      const char *name, double x, double y, double z,
+						      const HklUnit *punit)
 {
 	HklParameter *axis = NULL;
 	size_t i, idx;
@@ -175,7 +184,7 @@ HklParameter *hkl_holder_add_rotation_axis(HklHolder *self,
 	axis_v.data[1] = y;
 	axis_v.data[2] = z;
 
-	idx = hkl_geometry_add_rotation(self->geometry, name, &axis_v);
+	idx = hkl_geometry_add_rotation(self->geometry, name, &axis_v, punit);
 
 	/* check that the axis is not already in the holder */
 	for(i=0; i<self->config->len; i++)
@@ -733,6 +742,27 @@ int hkl_geometry_is_valid(const HklGeometry *self)
 	return TRUE;
 }
 
+/**
+ * hkl_geometry_is_valid_range: (skip)
+ * @self:
+ *
+ * check if all axes of the #HklGeometry are valid.
+ * (there is a difference for axis)
+ *
+ * Returns:
+ **/
+int hkl_geometry_is_valid_range(const HklGeometry *self)
+{
+	HklParameter **axis;
+
+	darray_foreach(axis, self->axes){
+		if(!hkl_parameter_is_valid_range(*axis))
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
 /**
  * hkl_geometry_closest_from_geometry_with_range: (skip)
  * @self:
@@ -769,6 +799,39 @@ int hkl_geometry_closest_from_geometry_with_range(HklGeometry *self,
 	return ko;
 }
 
+
+/**
+ * hkl_geometry_sample_rotation_get:
+ * @self: the self @HklGeometry@
+ * @sample: the rotated sample.
+ *
+ * return the rotation part of the given sample in the laboratory basis.
+ *
+ * Returns: the rotation express as a quaternion.
+ **/
+HklQuaternion hkl_geometry_sample_rotation_get(const HklGeometry *self,
+					       const HklSample *sample)
+{
+	return darray_item(self->holders, 0)->q;
+}
+
+/**
+ * hkl_geometry_detector_rotation_get:
+ * @self: the self @HklGeometry@
+ * @detector: the @HklDetector@
+ *
+ * return the rotation part of the given detector in the laboratory
+ * basis.
+ *
+ * Returns: the rotation express as a quaternion.
+ **/
+HklQuaternion hkl_geometry_detector_rotation_get(const HklGeometry *self,
+						 const HklDetector *detector)
+{
+	return darray_item(self->holders, detector->idx)->q;
+}
+
+
 /**
  * hkl_geometry_fprintf: (skip)
  * @file:
@@ -1158,7 +1221,7 @@ void hkl_geometry_list_remove_invalid(HklGeometryList *self)
 	HklGeometryListItem *item, *next;
 
 	list_for_each_safe(&self->items, item, next, list)
-		if(!hkl_geometry_is_valid(item->geometry)){
+		if(!hkl_geometry_is_valid_range(item->geometry)){
 			list_del(&item->list);
 			self->n_items--;
 			hkl_geometry_list_item_free(item);
