@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -216,6 +216,12 @@ HklGeometryList *hkl_engine_pseudo_axis_values_set(HklEngine *self,
 
 	solutions = hkl_geometry_list_new_copy(self->engines->geometries);
 
+#if LOGGING
+	hkl_geometry_list_fprintf(stream, solutions);
+	fflush(stream);
+	g_message(msg);
+#endif
+
 clean_stream_out:
 #if LOGGING
 	fclose(stream);
